:sd_hide_title:
.. grid:: 1

    .. grid-item-card:: PyXMake as a CI/CD Catalog project

        Learn how to use `PyXMake`_ components

------------------
General components
------------------

.. include:: ../../../README.md
	:start-line: 41
	:end-before: ## Contact
	:parser: myst_parser.docutils_

.. toctree::
   :hidden:
   :glob:
   
   ../pyx_catalog/project-config*
   ../pyx_catalog/project-archive*
   ../pyx_catalog/project-snapshot*
   ../pyx_catalog/project-mirror*
   ../pyx_catalog/project*

.. _PyXMake: https://pypi.org/project/pyxmake